// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
angular.module('starter', ['ionic', 'ngIOS9UIWebViewPatch', 'starter.controllers', 'starter.services', 'ngCordova'])

.run(function($ionicPlatform, $cordovaSQLite) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if(window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
    }
    if(window.StatusBar) {
      StatusBar.styleDefault();
    }

    if(window.cordova) {
      // App syntax
      db = window.sqlitePlugin.openDatabase("sjapp.db");
    } else {
      // Ionic serve syntax
      db = window.openDatabase("sjapp.db", "1.0", "SJ app", -1);
    }
 
    // $cordovaSQLite.execute(db, "DROP TABLE savedJobs");
    $cordovaSQLite.execute(db, "CREATE TABLE IF NOT EXISTS savedJobs"+ 
      "("+
      "jobid integer primary key,"+ 
      "agency_id integer,"+ 
      "position_title VARCHAR(100),"+
      "available_positions VARCHAR(100),"+
      "vessel_type VARCHAR(100),"+
      "opening_date VARCHAR(100),"+
      "closing_date VARCHAR(100),"+
      "benefits VARCHAR(100),"+
      "description longtext,"+
      "establishment_name VARCHAR(100),"+
      "establishment_address VARCHAR(250),"+
      "establishment_contact VARCHAR(100),"+
      "establishment_poea_no VARCHAR(100)"+
      ")"
    );
    
    // $cordovaSQLite.execute(db, "DROP TABLE seaExperience");
    $cordovaSQLite.execute(db, "CREATE TABLE IF NOT EXISTS seaExperience"+ 
      "("+
      "id integer primary key autoincrement,"+ 
      "position_id VARCHAR(100),"+ 
      "position VARCHAR(100),"+ 
      "other_position VARCHAR(100),"+
      "manning_agency VARCHAR(100),"+
      "vessel_name VARCHAR(100),"+
      "vessel_type_id VARCHAR(100),"+
      "vessel_type VARCHAR(100),"+
      "other_vessel_type VARCHAR(100),"+
      "grt VARCHAR(100),"+
      "trade_route VARCHAR(100),"+
      "signon_date VARCHAR(100),"+
      "signoff_date VARCHAR(100)"+
      ")"
    );

    // $cordovaSQLite.execute(db, "DROP TABLE landExperience");
    $cordovaSQLite.execute(db, "CREATE TABLE IF NOT EXISTS landExperience"+ 
      "("+
      "id integer primary key autoincrement,"+ 
      "land_position VARCHAR(100),"+ 
      "employer VARCHAR(100),"+
      "work_site VARCHAR(100),"+
      "from_date VARCHAR(100),"+
      "to_date VARCHAR(100)"+
      ")"
    );

  });
})

.config(function($stateProvider, $urlRouterProvider, $httpProvider) {

  $httpProvider.defaults.headers.post["Content-Type"] = "application/x-www-form-urlencoded";
  //Enable cross domain calls
  // $httpProvider.defaults.useXDomain = true;
  //Remove the header used to identify ajax call  that would prevent CORS from working
  delete $httpProvider.defaults.headers.common['X-Requested-With'];

  $stateProvider

  .state('home', {
      cache: false,
      url: "/",
      templateUrl: "templates/home.html",
      controller: 'HomeController'
  })

  .state('login', {
      url: "/login",
      templateUrl: "templates/login.html",
      controller: 'LoginController'
  })
  .state('login-first',{
      url: "/login/:error/:jobid/:agency_id",
      templateUrl: "templates/login.html",
      controller: 'LoginController'
  })
  .state('register', {
      cache: false,
      url: "/register",
      templateUrl: "templates/register.html",
      controller: 'RegisterController'
  })
  .state('profile', {
      cache: false,
      url: "/profile",
      templateUrl: "templates/profile.html",
      controller: 'ProfileController'
  })

  .state('edit-resume', {
      cache: false,
      url: "/edit-resume/:form",
      templateUrl: "templates/edit-resume.html",
      controller: 'EditController'
  })

  .state('edit-resume-exp', {
      cache: false,
      url: "/edit-resume/:form/:id",
      templateUrl: "templates/edit-resume.html",
      controller: 'EditController'
  })

  .state('jobs', {
      url: "/jobs/:what/:search_by",
      templateUrl: "templates/jobs.html",
      controller: 'JobsController'
  })

  .state('agency-jobs', {
      url: "/jobs/:agency_id",
      templateUrl: "templates/jobs.html",
      controller: 'JobsController'
  })

  .state('job-details', {
      url: "/job-details/:jobid/:agency_id/:success",
      templateUrl: "templates/job-details.html",
      controller: 'JobDetailsController'
  })

  .state('apply', {
      cache: false,
      url: "/apply/:jobid/:agency_id",
      templateUrl: "templates/apply.html",
      controller: 'applyController'
  })

  .state('apply-saved', {
      cache: false,
      url: "/apply/:jobid/:agency_id/:saved",
      templateUrl: "templates/apply.html",
      controller: 'applyController'
  })

  .state('saved-jobs', {
      cache: false,
      url: "/saved-jobs",
      templateUrl: "templates/saved-jobs.html",
      controller: 'SavedJobsController'
  })

  .state('saved-job-details', {
      url: "/saved-job-details/:jobid/:agency_id/:success",
      templateUrl: "templates/saved-job-details.html",
      controller: 'SavedJobDetailsController'
  })

  .state('jobs-applied', {
      cache: false,
      url: "/jobs-applied",
      templateUrl: "templates/jobs-applied.html",
      controller: 'JobsAppliedController'
  })

  .state('job-alerts', {
      cache: false,
      url:"/job-alerts",
      templateUrl: "templates/job-alerts.html",
      controller: 'JobAlertsController'
  })

  $urlRouterProvider.otherwise('/');
});
