angular.module('starter.services', [])

.factory('LocalStorage',['$window', function($window){
  var prefix = 'sj_';
  
  return {

    set: function(key, value) {
      $window.localStorage[prefix+key] = value;
    },

    get: function(key, defaultValue) {
      return $window.localStorage[prefix+key] || null;
    },

    setObject: function(key, value) {
      $window.localStorage[prefix+key] = JSON.stringify(value);
    },

    getObject: function(key) {
      return JSON.parse($window.localStorage[prefix+key] || '{}');
    },

    remove: function(key) {
      $window.localStorage.removeItem(prefix+key);
    },

    clear: function () {
      $window.localStorage.clear();
    }
    
  }
}])

.factory("transformRequestAsFormPost", function() {

    function transformRequest( data, getHeaders ) {
        var headers = getHeaders();
        headers[ "Content-type" ] = "application/x-www-form-urlencoded";
        return( serializeData( data ) );
    }
    return( transformRequest );

    /** Private method */
    function serializeData( data ) {
        if ( ! angular.isObject( data ) ) {
            return( ( data == null ) ? "" : data.toString() );
        }
        var buffer = [];
        // Serialize each key in the object.
        for ( var name in data ) {
            if ( ! data.hasOwnProperty( name ) ) {
                continue;
            }
            var value = data[ name ];
            buffer.push(
                encodeURIComponent( name ) +
                "=" +
                encodeURIComponent( ( value == null ) ? "" : value )
            );
        }
        // Serialize the buffer and clean it up for transportation.
        var source = buffer.join( "&" ).replace( /%20/g, "+" );
        return( source );
    }
})

.factory('Toast', function($rootScope, $timeout, $ionicPopup, $cordovaToast) {
  
    return {
        show: function (message, duration, position) {
          message = message || "There was a problem...";
          duration = duration || 'short';
          position = position || 'bottom';

          if (!!window.cordova) {
            $cordovaToast.show(message, duration, position);
          } else {

            if (!duration) {
              duration = 5000;
            }

            var myPopup = $ionicPopup.show({
              template: "<div class='toast'>" + message + "</div>",
              scope: $rootScope,
              buttons: []
            });

            $timeout(function() {
              myPopup.close(); 
            }, duration);
          }
    }
  };
})

.factory('Obj', function ($rootScope) {
  
  function size(obj)
  {
    var size = 0, key;
    for (key in obj) {
        if (obj.hasOwnProperty(key)) size++;
    }
    return size;
  }

  return {
    size:size
  };
})

.factory('Dialog', function($ionicPopup, $cordovaDialogs, $q){

    function alert(message, title, button, callback)
    {

        if (!window.cordova)
        {
            $ionicPopup.alert({
               title: title,
               template: message
            }).then(callback);
        } else {
            $cordovaDialogs.alert(message, title, button).then(callback);
        }

    }

    function confirm(title, template, callback, button) {
      if (!window.cordova)
      {
        var confirmPopup = $ionicPopup.confirm({
          title: title,
          template: template
        }).then(callback);
      } else {
        $cordovaDialogs.confirm(template, title, button)
        .then(function(buttonIndex) {
            callback(buttonIndex);
        });

      }
      
    }
    return ({
      alert:alert,
      confirm:confirm
    });
})
.factory('Network', function($cordovaNetwork, Dialog){
    function isOfline()
    {
        if (window.cordova)
        {
            if ($cordovaNetwork.isOffline())
            {   
                Dialog.alert('No network connection.', 'Network Connection', 'Ok', function(){});
                return true;
            }
        }
    }
    return ({
      isOfline: isOfline
    });
})
.factory('DBA', function($cordovaSQLite, $q, $ionicPlatform) {
  var self = this;
 
  // Handle query's and potential errors
  self.query = function (query, parameters) {
    parameters = parameters || [];
    var q = $q.defer();
 
    $ionicPlatform.ready(function () {
      $cordovaSQLite.execute(db, query, parameters)
        .then(function (result) {
          q.resolve(result);
        }, function (error) {
          console.warn('I found an error');
          console.warn(error);
          q.reject(error);
        });
    });
    return q.promise;
  }
 
  // Proces a result set
  self.getAll = function(result) {
    var output = [];
 
    for (var i = 0; i < result.rows.length; i++) {
      output.push(result.rows.item(i));
    }
    return output;
  }
 
  // Proces a single result
  self.getById = function(result) {
    var output = null;
    if(result.rows.length > 0){
      output = angular.copy(result.rows.item(0));
    }
    
    return output;
  }
 
  return self;
})
.factory('Jobs', function($cordovaSQLite, DBA) {
  var self = this;
  var job_fields = "jobid,agency_id,position_title,available_positions,vessel_type,opening_date,closing_date,benefits,description,establishment_name,establishment_address,establishment_contact,establishment_poea_no";
  var sea_fields = "position_id, position, other_position, manning_agency, vessel_name, vessel_type_id, vessel_type, other_vessel_type, grt, trade_route, signon_date, signoff_date";
  var land_fields = "land_position, employer, work_site, from_date, to_date";

  self.all = function(table) {
    if(table == 'savedJobs'){
      var fields = job_fields;
    }
    else if(table == 'seaExperience'){
      var fields = 'id,'+sea_fields;
    }
    else if(table == 'landExperience'){
      var fields = 'id,'+land_fields;
    }
    return DBA.query("SELECT "+ fields +" FROM " + table)
      .then(function(result){
        return DBA.getAll(result);
      });
  }
 
  self.get = function(jobId) {
    var parameters = [jobId];
    return DBA.query("SELECT "+ job_fields +" FROM savedJobs WHERE jobid = (?)", parameters)
      .then(function(result) {
        return DBA.getById(result);
      });
  }

  self.getExp = function(table, id){
    var parameters = [id];
    if(table == 'seaExperience'){
      var fields = 'id,'+sea_fields;
    }
    else if(table == 'landExperience'){
      var fields = 'id,'+land_fields;
    }
    return DBA.query("SELECT "+ fields + " FROM "+ table +" WHERE id = (?)", parameters)
      .then(function(result){
        return DBA.getById(result);
      })
  }
 
  self.add = function(job) {
    var parameters = [job.jobid, job.agency_id, job.position_title, job.available_positions, job.vessel_type, job.opening_date,job.closing_date,job.benefits,job.description,job.establishment_name,job.establishment_address,job.establishment_contact,job.establishment_poea_no];
    return DBA.query("INSERT INTO savedJobs ("+ job_fields +") VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)", parameters);
  }

  self.addSeaExp = function(sea){
    var parameters = [sea.position_id, sea.position,sea.other_position, sea.manning_agency, sea.vessel_name, sea.vessel_type_id, sea.vessel_type, sea.other_vessel_type, sea.grt, sea.trade_route, sea.signon_date, sea.signoff_date];
    return DBA.query("INSERT INTO seaExperience ("+ sea_fields +") VALUES (?,?,?,?,?,?,?,?,?,?,?,?)", parameters);
  }

  self.addLandExp = function(land){
    var parameters = [land.land_position, land.employer, land.work_site, land.from_date, land.to_date];
    return DBA.query("INSERT INTO landExperience ("+ land_fields +") VALUES (?,?,?,?,?)", parameters);
  }
 
  self.updateSeaExp = function(sea,id){
    return DBA.query("UPDATE seaExperience SET position_id='"+sea.position_id+"', position='"+sea.position+"', other_position='"+sea.other_position+"', manning_agency='"+sea.manning_agency
    +"', vessel_name='"+sea.vessel_name+"', vessel_type_id='"+sea.vessel_type_id+"', vessel_type='"+sea.vessel_type+"', other_vessel_type='"+sea.other_vessel_type+"', grt='"+sea.grt+"', trade_route='"+sea.trade_route
    +"', signon_date='"+sea.signon_date+"', signoff_date='"+sea.signoff_date+"' WHERE id = (?)", [id]);
  }

  self.updateLandExp = function(land,id){
    return DBA.query("UPDATE landExperience SET land_position='"+land.land_position+"', employer='"+land.employer+"', work_site='"+land.work_site+"', from_date='"+land.from_date
    +"', to_date='"+land.to_date+"' WHERE id = (?)", [id]);
  }

  self.remove = function(table, field, value) {
    var parameters = [value];
    return DBA.query("DELETE FROM "+ table +" WHERE "+ field +" = (?)", parameters);
  }

  self.removeAll = function(table) {
    return DBA.query("DELETE FROM "+ table);
  }
  
  return self;
})